@@ -45,41 +45,29 @@ for the Bubble renderer.
 
 =head1 METHODS
 
-=head2 Constructors
-
-=over 4
-
-=item I<new>
+=head2 new
 
 Creates a new, empty Series::Size
 
-=back
-
-=head2 Methods
-
-=over 4
-
-=item I<add_to_sizes>
+=head2 add_to_sizes
 
 Adds a size to this series.
 
-=item I<get_size>
+=head2 get_size
 
 Get a size by it's index.
 
-=item I<sizes>
+=head2 sizes
 
 Set/Get the sizes for this series.
 
-=item I<size_count>
+=head2 size_count
 
 Gets the count of sizes in this series.
 
-=back
-
 =head1 AUTHOR
 
-Cory 'G' Watson <jheephat@cpan.org>
+Cory 'G' Watson <gphat@cpan.org>
 
 =head1 LICENSE
 
